package com.totopia.server.modules.info.controller;

import com.totopia.server.commons.data.payload.ApiResponse;
import com.totopia.server.modules.info.entity.FreeBoardEntity;
import com.totopia.server.modules.info.service.FreeBoardService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.data.web.SortDefault;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

@RestController
public class FreeBoardController {

  @Autowired
  private FreeBoardService freeBoardService;

  @PostMapping(value = "/free-board")
  @ResponseStatus(code = HttpStatus.CREATED)
  public ResponseEntity<?> save(@Valid @RequestBody FreeBoardEntity freeBoardEntity) throws Exception{
    this.freeBoardService.save(freeBoardEntity);
    return ResponseEntity.ok().body(new ApiResponse(true, "FreeBoard registered successfully"));
  }

  @GetMapping(value = "/free-board")
  public Page<FreeBoardEntity> all(
      @SortDefault.SortDefaults({
          @SortDefault(
              sort = "createdAt",
              direction = Sort.Direction.DESC) })
          Pageable pageable) {
    return this.freeBoardService.getAllByPageable(pageable);
  }
//
//  @GetMapping(value = "/users/{userId}")
//  public UserEntity findByUserId(@PathVariable Long userId) {
//    return this.userService.getUserById(userId);
//  }
  @GetMapping(value = "/free-board/{boardId}")
  public FreeBoardEntity findById(
      @PathVariable Long boardId) {
    return this.freeBoardService.getBoardById(boardId);
  }

  @PutMapping(value = "/free-board/{boardId}")
  public ResponseEntity<?> modify(@PathVariable Long boardId, FreeBoardEntity freeBoardEntity) throws Exception {
    FreeBoardEntity board = this.freeBoardService.modify(freeBoardEntity);
    return ResponseEntity.ok(board);
  }

  @DeleteMapping(value = "/free-board/{boardId}")
  public ResponseEntity<?> removeById(@PathVariable Long boardId) {
    Long res = this.freeBoardService.removeById(boardId);
    return ResponseEntity.ok(res);
  }
}
